==> open-cluster-management-cluster-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ManagedClusterSetListFluent<A extends ManagedClusterSetListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ManagedClusterSet item);
  public A setToItems(Integer index,ManagedClusterSet item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public A addAllToItems(Collection<ManagedClusterSet> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public A removeAllFromItems(Collection<ManagedClusterSet> items);
  public A removeMatchingFromItems(Predicate<ManagedClusterSetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ManagedClusterSet> getItems();
  public List<ManagedClusterSet> buildItems();
  public ManagedClusterSet buildItem(Integer index);
  public ManagedClusterSet buildFirstItem();
  public ManagedClusterSet buildLastItem();
  public ManagedClusterSet buildMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public A withItems(List<ManagedClusterSet> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public Boolean hasItems();
  public ManagedClusterSetListFluent.ItemsNested<A> addNewItem();
  public ManagedClusterSetListFluent.ItemsNested<A> addNewItemLike(ManagedClusterSet item);
  public ManagedClusterSetListFluent.ItemsNested<A> setNewItemLike(Integer index,ManagedClusterSet item);
  public ManagedClusterSetListFluent.ItemsNested<A> editItem(Integer index);
  public ManagedClusterSetListFluent.ItemsNested<A> editFirstItem();
  public ManagedClusterSetListFluent.ItemsNested<A> editLastItem();
  public ManagedClusterSetListFluent.ItemsNested<A> editMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ManagedClusterSetFluent<ManagedClusterSetListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ManagedClusterSetListFluent<A extends ManagedClusterSetListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ManagedClusterSet item);
  public A setToItems(int index,ManagedClusterSet item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public A addAllToItems(Collection<ManagedClusterSet> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public A removeAllFromItems(Collection<ManagedClusterSet> items);
  public A removeMatchingFromItems(Predicate<ManagedClusterSetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ManagedClusterSet> getItems();
  public List<ManagedClusterSet> buildItems();
  public ManagedClusterSet buildItem(int index);
  public ManagedClusterSet buildFirstItem();
  public ManagedClusterSet buildLastItem();
  public ManagedClusterSet buildMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public A withItems(List<ManagedClusterSet> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1beta1.ManagedClusterSet... items);
  public Boolean hasItems();
  public ManagedClusterSetListFluent.ItemsNested<A> addNewItem();
  public ManagedClusterSetListFluent.ItemsNested<A> addNewItemLike(ManagedClusterSet item);
  public ManagedClusterSetListFluent.ItemsNested<A> setNewItemLike(int index,ManagedClusterSet item);
  public ManagedClusterSetListFluent.ItemsNested<A> editItem(int index);
  public ManagedClusterSetListFluent.ItemsNested<A> editFirstItem();
  public ManagedClusterSetListFluent.ItemsNested<A> editLastItem();
  public ManagedClusterSetListFluent.ItemsNested<A> editMatchingItem(Predicate<ManagedClusterSetBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ManagedClusterSetFluent<ManagedClusterSetListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
